@@ -69,8 +69,8 @@ static const unsigned char block_size[16] =
 static gboolean gst_amrwbdec_start (GstAudioDecoder * dec);
 static gboolean gst_amrwbdec_stop (GstAudioDecoder * dec);
 static gboolean gst_amrwbdec_set_format (GstAudioDecoder * dec, GstCaps * caps);
-static gboolean gst_amrwbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
-    gint * offset, gint * length);
+static GstFlowReturn gst_amrwbdec_parse (GstAudioDecoder * dec,
+    GstAdapter * adapter, gint * offset, gint * length);
 static GstFlowReturn gst_amrwbdec_handle_frame (GstAudioDecoder * dec,
     GstBuffer * buffer);
 
@@ -83,10 +83,8 @@ gst_amrwbdec_class_init (GstAmrwbDecClass * klass)
   GstAudioDecoderClass *base_class = GST_AUDIO_DECODER_CLASS (klass);
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_template));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_static_pad_template (element_class, &sink_template);
+  gst_element_class_add_static_pad_template (element_class, &src_template);
 
   gst_element_class_set_static_metadata (element_class, "AMR-WB audio decoder",
       "Codec/Decoder/Audio",
